Simple Django Menus
===================

.. image:: https://img.shields.io/travis/borgstrom/django-simple-menu.svg
           :target: https://travis-ci.org/borgstrom/django-simple-menu

.. image:: https://img.shields.io/codecov/c/github/borgstrom/django-simple-menu.svg
           :target: https://codecov.io/github/borgstrom/django-simple-menu

.. image:: https://img.shields.io/pypi/v/django-simple-menu.svg
           :target: https://pypi.python.org/pypi/django-simple-menu
           :alt: Latest PyPI version

.. image:: https://img.shields.io/pypi/dm/django-simple-menu.svg
           :target: https://pypi.python.org/pypi/django-simple-menu
           :alt: Number of PyPI downloads

django-simple-menu is an entirely code based menu system, because, who
really wants to define their menus in the django admin...

It's simple to use, yet provides enough flexibility to provide unlimited
children menus, per-request generation and checking of menu items, badges,
and more.

It was built from scratch over the past 3 years as part of an internal
system after we were not satisifed by all of the existing menu apps.

Documentation
-------------
The documentation is located in the docs directory and can be viewed at:

https://django-simple-menu.readthedocs.org

Requirements
------------
Django 1.3+
